Module priority

Module priority 

Sampling priority constants.

These values indicate whether a trace should be kept or rejected, and whether the decision was made automatically or by the user.

Constants

AUTO_KEEP
Automatically kept by the sampler (priority 1).
AUTO_REJECT
Automatically rejected by the sampler (priority 0).
USER_KEEP
User explicitly requested to keep this trace (priority 2).
USER_REJECT
User explicitly rejected this trace (priority -1).