pub struct SamplingDecision {
pub priority: Option<SamplingPriority>,
pub mechanism: Option<SamplingMechanism>,
}Expand description
Represents a sampling decision for a trace.
Contains the priority level and the mechanism that made the decision.
Fields
priority: Option<SamplingPriority>The sampling priority indicating whether the trace should be kept or rejected.
mechanism: Option<SamplingMechanism>The mechanism that made the sampling decision.