Sampling priority constants.
These values indicate whether a trace should be kept or rejected, and whether the decision was made automatically or by the user.
Constants
- AUTO_
KEEP - Automatically kept by the sampler (priority 1).
- AUTO_
REJECT - Automatically rejected by the sampler (priority 0).
- USER_
KEEP - User explicitly requested to keep this trace (priority 2).
- USER_
REJECT - User explicitly rejected this trace (priority -1).