pub struct SamplingPriority { /* private fields */ }Expand description
Represents the sampling priority of a trace.
Positive values indicate the trace should be kept, while zero or negative
values indicate rejection. Use the constants in the priority module
for standard priority values.
Implementations
Sourceimpl SamplingPriority
impl SamplingPriority
pub const fn from_i8(value: i8) -> Self
pub fn into_i8(self) -> i8
Sourcepub fn is_keep(&self) -> bool
pub fn is_keep(&self) -> bool
Returns whether this sampling priority indicates the trace should be kept.
Returns
true if the priority value is positive (indicating the trace should be kept),
false otherwise (indicating the trace should be dropped).
Examples
use libdd_sampling::priority;
assert!(priority::AUTO_KEEP.is_keep());
assert!(priority::USER_KEEP.is_keep());
assert!(!priority::AUTO_REJECT.is_keep());
assert!(!priority::USER_REJECT.is_keep());Trait Implementations
Sourceimpl Clone for SamplingPriority
impl Clone for SamplingPriority
Sourcefn clone(&self) -> SamplingPriority
fn clone(&self) -> SamplingPriority
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SamplingPriority
impl Debug for SamplingPriority
Sourceimpl Display for SamplingPriority
impl Display for SamplingPriority
Sourceimpl FromStr for SamplingPriority
impl FromStr for SamplingPriority
Sourceimpl Hash for SamplingPriority
impl Hash for SamplingPriority
Sourceimpl PartialEq for SamplingPriority
impl PartialEq for SamplingPriority
Sourcefn eq(&self, other: &SamplingPriority) -> bool
fn eq(&self, other: &SamplingPriority) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for SamplingPriority
impl Eq for SamplingPriority
impl StructuralPartialEq for SamplingPriority